pub struct Chunk {
pub reference_time: OffsetDateTime,
pub events: Vec<Event>,
}Expand description
A chunk of metrics that represents all events emitted from the reference_time
through 65 seconds after that reference time.
Fields
reference_time: OffsetDateTimeThe start time of this chunk
events: Vec<Event>The events that have happened within 65 seconds of the reference time
Implementations
Sourceimpl Chunk
impl Chunk
Sourcepub fn new(reference_time: OffsetDateTime) -> Self
pub fn new(reference_time: OffsetDateTime) -> Self
Create a new chunk from the provided time
Sourcepub fn memory_size(&self) -> usize
pub fn memory_size(&self) -> usize
A naive method for trying to determine the total memory size used by this chunk