pub struct LabelSet(pub BTreeMap<Key, u16>);Expand description
A set of labels mapping from the original metrics::Key to a unique identifier
and will be used to lookup what identifier to use when recording metrics events
Tuple Fields
0: BTreeMap<Key, u16>Implementations