pub struct MetricRef<'a> {
pub when: OffsetDateTime,
pub event: Entry,
pub key: &'a Key,
}Expand description
A single event borrowed from the Procession, this representation will not cause any additional allocations and can be serialized, the timestamp is re-calculated as part of the construction but no other computation should occur.
Fields
when: OffsetDateTimeThe time this event occurred
event: EntryThe value emitted for the key
key: &'a KeyThe key and labels provided by the metrics crate